@@ -10,3 +10,7 @@ REF_TAG = "$ref"
 STDIN = pathlib.Path("/dev/stdin")
 
 STDOUT = pathlib.Path("/dev/stdout")
+
+YAML_EXT = frozenset(['.yaml', '.yml'])
+
+JSON_EXT = frozenset(['.json'])
