@@ -7,8 +7,8 @@ from .log import log
 from .constant import STDIN
 
 
-def path_type(path):
-    if path == "-":
+def path_type(path, allow_stdin=False):
+    if allow_stdin and path == "-":
         return STDIN
     return pathlib.Path(os.path.expanduser(path)).resolve()
 
